@@ -34,7 +34,7 @@
 #include <QPushButton>
 #include <QStandardPaths>
 #include <QStyle>
-#include <QStyleOptionViewItemV4>
+#include <QStyleOptionViewItem>
 
 #include <QDebug>
 #include <kurllabel.h>
@@ -55,8 +55,8 @@
 KPluginSelector::Private::Private(KPluginSelector *parent)
     : QObject(parent)
     , parent(parent)
-    , listView(0)
-    , categoryDrawer(0)
+    , listView(nullptr)
+    , categoryDrawer(nullptr)
     , showIcons(false)
 {
 }
@@ -118,7 +118,7 @@ KPluginSelector::Private::DependenciesWidget::DependenciesWidget(QWidget *parent
 
     details = new QLabel();
 
-    QHBoxLayout *layout = new QHBoxLayout;
+    QHBoxLayout *layout = new QHBoxLayout(this);
 
     QVBoxLayout *dataLayout = new QVBoxLayout;
     dataLayout->setAlignment(Qt::AlignLeft | Qt::AlignVCenter);
@@ -141,7 +141,6 @@ KPluginSelector::Private::DependenciesWidget::DependenciesWidget(QWidget *parent
     dataLayout->addWidget(link);
     dataLayout->addWidget(details);
     layout->addLayout(dataLayout);
-    setLayout(layout);
 
     QObject::connect(link, SIGNAL(leftClickedUrl()), this, SLOT(showDependencyDetails()));
 }
@@ -254,9 +253,8 @@ KPluginSelector::KPluginSelector(QWidget *parent)
     : QWidget(parent)
     , d(new Private(this))
 {
-    QVBoxLayout *layout = new QVBoxLayout;
+    QVBoxLayout *layout = new QVBoxLayout(this);
     layout->setMargin(0);
-    setLayout(layout);
 
     d->lineEdit = new QLineEdit(this);
     d->lineEdit->setClearButtonEnabled(true);
@@ -304,7 +302,7 @@ void KPluginSelector::addPlugins(const QString &componentName,
 {
     QStringList desktopFileNames;
     const QStringList dirs = QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, componentName + QStringLiteral("/kpartplugins"), QStandardPaths::LocateDirectory);
-    Q_FOREACH (const QString &dir, dirs) {
+    for (const QString &dir : dirs) {
         QDirIterator it(dir, QStringList() << QStringLiteral("*.desktop"), QDir::NoFilter, QDirIterator::Subdirectories);
         while (it.hasNext()) {
             desktopFileNames.append(it.next());
@@ -449,7 +447,7 @@ void KPluginSelector::Private::PluginModel::addPlugins(const QList<KPluginInfo>
         pluginEntry.isCheckable = !pluginInfo.isValid() || !pluginEntry.cfgGroup.isEntryImmutable(pluginInfo.pluginName() + QLatin1String("Enabled"));
 
         if (!pluginEntryList.contains(pluginEntry) && !listToAdd.contains(pluginEntry) &&
-                (pluginInfo.category().isEmpty() || !pluginInfo.category().compare(categoryKey, Qt::CaseInsensitive)) &&
+                (categoryKey.isEmpty() || !pluginInfo.category().compare(categoryKey, Qt::CaseInsensitive)) &&
                 (!pluginInfo.service() || !pluginInfo.service()->noDisplay())) {
             listToAdd << pluginEntry;
 
@@ -476,7 +474,7 @@ QModelIndex KPluginSelector::Private::PluginModel::index(int row, int column, co
     Q_UNUSED(parent)
 
     return createIndex(row, column, (row < pluginEntryList.count()) ? (void *) &pluginEntryList.at(row)
-                       : 0);
+                       : nullptr);
 }
 
 QVariant KPluginSelector::Private::PluginModel::data(const QModelIndex &index, int role) const
@@ -609,14 +607,12 @@ void KPluginSelector::Private::PluginDelegate::paint(QPainter *painter, const QS
 
     painter->save();
 
-    QApplication::style()->drawPrimitive(QStyle::PE_PanelItemViewItem, &option, painter, 0);
+    QApplication::style()->drawPrimitive(QStyle::PE_PanelItemViewItem, &option, painter, nullptr);
 
     int iconSize = option.rect.height() - MARGIN * 2;
     if (pluginSelector_d->showIcons) {
-        QPixmap pixmap = KIconLoader::global()->loadIcon(index.model()->data(index, Qt::DecorationRole).toString(),
-                         KIconLoader::Desktop, iconSize, disabled ? KIconLoader::DisabledState : KIconLoader::DefaultState);
-
-        painter->drawPixmap(QRect(pluginSelector_d->dependantLayoutValue(MARGIN + option.rect.left() + xOffset, iconSize, option.rect.width()), MARGIN + option.rect.top(), iconSize, iconSize), pixmap, QRect(0, 0, iconSize, iconSize));
+        QIcon icon = QIcon::fromTheme(index.model()->data(index, Qt::DecorationRole).toString());
+        icon.paint(painter, QRect(pluginSelector_d->dependantLayoutValue(MARGIN + option.rect.left() + xOffset, iconSize, option.rect.width()), MARGIN + option.rect.top(), iconSize, iconSize));
     } else {
         iconSize = -MARGIN;
     }
@@ -807,10 +803,10 @@ void KPluginSelector::Private::PluginDelegate::slotConfigureClicked()
     QDialog configDialog(itemView());
     configDialog.setWindowTitle(model->data(index, NameRole).toString());
     // The number of KCModuleProxies in use determines whether to use a tabwidget
-    QTabWidget *newTabWidget = 0;
+    QTabWidget *newTabWidget = nullptr;
     // Widget to use for the setting dialog's main widget,
     // either a QTabWidget or a KCModuleProxy
-    QWidget *mainWidget = 0;
+    QWidget *mainWidget = nullptr;
     // Widget to use as the KCModuleProxy's parent.
     // The first proxy is owned by the dialog itself
     QWidget *moduleProxyParentWidget = &configDialog;
@@ -834,9 +830,9 @@ void KPluginSelector::Private::PluginDelegate::slotConfigureClicked()
                         mainWidget = newTabWidget;
                     } else {
                         delete newTabWidget;
-                        newTabWidget = 0;
+                        newTabWidget = nullptr;
                         moduleProxyParentWidget = &configDialog;
-                        mainWidget->setParent(0);
+                        mainWidget->setParent(nullptr);
                     }
                 }
 
